package org.rominos2.SeasonsMobSpawn;

import java.io.File;
import java.util.ArrayList;
import java.util.logging.Logger;

import org.bukkit.World;
import org.bukkit.event.Event;
import org.bukkit.plugin.PluginManager;
import org.bukkit.plugin.java.JavaPlugin;
import org.rominos2.Seasons.api.Seasons;
import org.rominos2.Seasons.api.Managers.SeasonsManager;
import org.rominos2.SeasonsMobSpawn.Listeners.*;

public class SeasonsMobSpawn extends JavaPlugin {
	private Logger logger = Logger.getLogger("Minecraft");
	private final String maindirString="plugins/Seasons/MobSpawn/";
	private SeasonsMobSpawnEntityListener entityListener;
	private SeasonsMobSpawnSeasonsListener seasonsListener;
	private ArrayList<SeasonsMobSpawnManager> spawnManagers = new ArrayList<SeasonsMobSpawnManager>();
	private Seasons plugin;

	public void onEnable() {
		if (!new File(maindirString).exists()) {
			new File(maindirString).mkdir();
			this.logger.info("[SeasonsMobSpawn] SeasonsMobSpawn Folder created.");
		}//if no folder
		
		if (!this.getServer().getPluginManager().isPluginEnabled("Seasons")) {
			this.logger.info("[SeasonsMobSpawn] Seasons is not detected, disabling...");
			this.getServer().getPluginManager().disablePlugin(this);
			return;
		}//if Seasons not enabled
		
		this.plugin = (Seasons) this.getServer().getPluginManager().getPlugin("Seasons");
		
		for (SeasonsManager manager : this.plugin.getManagers()) {
			if (!manager.getProperties().isActive()) {
				continue;
			}//if not active
			this.loadWorld(manager);
		}//for managers
		
		this.entityListener = new SeasonsMobSpawnEntityListener(this);
		this.seasonsListener = new SeasonsMobSpawnSeasonsListener(this);
		
		PluginManager plugman = this.getServer().getPluginManager();
		plugman.registerEvent(Event.Type.CREATURE_SPAWN, this.entityListener, Event.Priority.Normal, this);
		plugman.registerEvent(Event.Type.CUSTOM_EVENT, this.seasonsListener, Event.Priority.Normal, this);
		this.logger.info("[SeasonsMobSpawn] Plugin SeasonsMobSpawn, by Rominos2, version "+this.getDescription().getVersion()+", is enabled.");
	}//onEnable
	
	public void onDisable() {
		this.logger.info("[SeasonsMobSpawn] Plugin SeasonsMobSpawn, by Rominos2, version "+this.getDescription().getVersion()+", is disabled.");
	}//onDisable
	
	public String getMainDirString() {
		return this.maindirString;
	}//getMainDir
	public Logger getLogger() {
		return this.logger;
	}//getLogger
	
	public ArrayList<SeasonsMobSpawnManager> getSpawnManagers() {
		return this.spawnManagers;
	}//getProperties
	public SeasonsMobSpawnManager getSpawnManager(World world) {
		for (SeasonsMobSpawnManager spawnManager : this.spawnManagers) {
			if (spawnManager.getWorld().getName().equalsIgnoreCase(world.getName())) {
				return spawnManager;
			}//if same name
		}//for settings
		return null;
	}//getProperties
	
	public void loadWorld(SeasonsManager manager) {
		SeasonsMobSpawnManager settings = new SeasonsMobSpawnManager(this, manager);
		settings.load();
		this.spawnManagers.add(settings);
	}//loadWorld

}//class SeasonsMobSpawn
