package org.rominos2.SeasonsMobSpawn;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;

import org.bukkit.World;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.entity.CreatureType;
import org.rominos2.Seasons.api.SeasonObject;
import org.rominos2.Seasons.api.Managers.SeasonsManager;

public class SeasonsMobSpawnManager {
	private SeasonsMobSpawn plugin;
	private SeasonsManager seasonsManager;
	private File file;
	private ArrayList<SeasonMobList> mobLists = new ArrayList<SeasonMobList>();
	private boolean mobsListedAreAuthorized;
	
	private boolean active;
	
	public SeasonsMobSpawnManager(SeasonsMobSpawn instance, SeasonsManager seasonsManager) {
		this.plugin = instance;
		this.seasonsManager = seasonsManager;
		this.file = new File(this.plugin.getMainDirString()+this.seasonsManager.getWorld().getName()+".yml");
	}//SeasonsMobSpawn
	
	public void load() {
		if (!this.file.exists()) {
			try {
				this.file.createNewFile();
				this.plugin.getLogger().info("[SeasonsMobSpawn] Properties not found for "+this.seasonsManager.getWorld().getName()+", created new ones");
				this.createSettings();
			}//try create file
			catch (IOException e) {
				e.printStackTrace();
			}//catch create file	
		}//if file no exists
		this.loadSettings();
	}//load
	
	private void loadSettings() {
		YamlConfiguration config = YamlConfiguration.loadConfiguration(this.file);
		this.active = config.getBoolean("Properties.Active", true);
		this.mobsListedAreAuthorized = config.getBoolean("Properties.AllowListedMobs", false);
		if (this.active) {
			this.loadSeasons(config);
		}
	}//loadSettings
	
	private void loadSeasons(YamlConfiguration config) {
		ConfigurationSection section = config.getConfigurationSection("Seasons");
		if (section==null) {
			this.plugin.getLogger().info("[SeasonsMobSpawn] No Seasons to hooked in for "+this.seasonsManager.getWorld().getName()+".");
			this.active = false;
			return;
		}//if nothing to load
		Iterator<String> iterator = section.getKeys(false).iterator();
		SeasonObject season;
		while (iterator.hasNext()) {
			season = this.seasonsManager.getProperties().getSeason(iterator.next());
			if (season==null) {
				continue;
			}//if null
			this.loadMobs(config, season);		
		}//while season
		this.plugin.getLogger().info("[SeasonsMobSpawn] Hooked into "+this.mobLists.size()+" seasons in "+this.seasonsManager.getWorld().getName()+".");
	}//loadSeasons
	
	private void createSettings() {
		YamlConfiguration config = YamlConfiguration.loadConfiguration(this.file);
		config.set("Properties.Active", true);
		//TODO Trouver un bon nom pour cette node
		config.set("Properties.AllowListedMobs", false);
		ArrayList<String> summerMobs = new ArrayList<String>();
		summerMobs.add("SKELETON");
		summerMobs.add("SNOWMAN");
		summerMobs.add("SPIDER");
		ArrayList<String> winterMobs = new ArrayList<String>();
		winterMobs.add("CHICKEN");
		winterMobs.add("COW");
		winterMobs.add("ENDERMAN");
		config.set("Seasons.Summer", summerMobs);
		config.set("Seasons.Winter",winterMobs);
		
		try {
			config.save(this.file);
		}//try save
		catch (IOException e) {
			e.printStackTrace();
		}//cacth save
	}//createSettings
	
	private void loadMobs(YamlConfiguration config, SeasonObject season) {
		SeasonMobList mobList = new SeasonMobList(season);
		@SuppressWarnings("unchecked")
		ArrayList<String> list = (ArrayList<String>) config.getList("Seasons."+season.getName());
		CreatureType mob;
		for (String string : list) {
			mob = CreatureType.valueOf(string);
			if (mob!=null) {
				mobList.addMob(mob);
			}//if not null
		}//for mobs
		this.mobLists.add(mobList);
	}//loadMobs
	
	public World getWorld() {
		return this.seasonsManager.getWorld();
	}//getWorld
	
	public boolean isActive() {
		return this.active;
	}//isActive
	
	public SeasonsManager getSeasonsManager() {
		return this.seasonsManager;
	}//getSeasonsManager
	
	public boolean canMobSpawn(CreatureType mob) {
		SeasonMobList mobList = this.getMobList(this.seasonsManager.getSeason());
		if (mobList==null) {
			return true;
		}//if null
		
		boolean listed = mobList.isMobListed(mob);
		if (this.mobsListedAreAuthorized) {
			return listed;
		}//if mobs authorized
		else {
			return !listed;
		}//if mobs forbidden
	}//canMobSpawn
	
	private SeasonMobList getMobList(SeasonObject season) {
		for (SeasonMobList spawn : this.mobLists) {
			if (spawn.getSeason().equals(season)) {
				return spawn;
			}//if same season
		}//for SpawnManagers
		return null;
	}//getSpawnManager

}//Class SeasonsMobSpawnSettings
